from sync import Exports
from parser import Parser
import click
import os
from settings_loader import settings_are_valid, update_configuration

@click.group()
def cli():
    pass

@cli.command(help='Download new exports')
@click.option('--config_id', help='Your config id', required=True)
@click.option('--new_name', help='file name of log file for new files', default='NEW')
@click.option('--changed_name', help='file name of log file for new files', default='CHANGED')
@click.argument('path')
def sync(config_id, path, new_name, changed_name):
    if settings_are_valid():
        update_configuration()
        if os.path.exists(path):
            if new_name and changed_name:
                exports = Exports(config_id, path)
                exports.sync_files(new_name, changed_name)
            else:
                print "new_name or changed_name can not be empty strings."
        else:
            print "Specified path does not exist"

@cli.command(help='See status of export')
@click.option('--config_id', help='Your config id', required=True)
@click.option('--json', is_flag=True, help='Outputs the info in JSON format')
@click.argument('path')
def info(config_id, json, path):
    if settings_are_valid():
        update_configuration()
        if os.path.exists(path):
            exports = Exports(config_id, path)
            if json:
                print exports.get_info_json()
            else:
                print exports.get_info_readable()
        else:
            print "Specified path does not exist"

@cli.command(help='Convert csv to json')
@click.option('--header_value', '-h', multiple=True)
@click.option('--new_files_file_name', default='NEW')
@click.option('--changed_files_file_name', default='CHANGED')
@click.option('--header/--no-header', default='True')
@click.argument('from_path')
@click.argument('to_path')
def convert(from_path, to_path, new_files_file_name, changed_files_file_name, header_value, header):
    parser = Parser(from_path, to_path, new_files_file_name, changed_files_file_name, header_value, header)
    parser.parse()

# Click
if __name__ == '__main__':
    cli()